@@ -9,8 +9,7 @@ from amazon.ion.json_encoder import IonToJSONEncoder
 class QLDBDriver:
     def __init__(self, ledger):
         self.qldb_driver = QldbDriver(ledger_name = ledger)
-        self.TABLE_CREATION_POLL_PERIOD_SEC = 5
-        self.TABLE_DELETION_POLL_PERIOD_SEC = 5
+        self.TABLE_CREATION_POLL_PERIOD_SEC = 2
     
     def to_collection(self, cursor):
         collection = []
@@ -32,13 +31,8 @@ class QLDBDriver:
         statement = f"CREATE TABLE {table_name}"
         self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
-        while True:
-            sleep(self.TABLE_CREATION_POLL_PERIOD_SEC)
-
-            if self.table_exists(table_name):
-                break
-
         if primary_key is not None:
+            sleep(self.TABLE_CREATION_POLL_PERIOD_SEC)
             statement = f"CREATE INDEX ON {table_name}({primary_key})"
             self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
@@ -109,12 +103,13 @@ class QLDBDriver:
 
 
     def insert_data(self, table_name, data):
-        statement = f"INSERT INTO {table_name} `{json.dumps(data)}`"
+	    raw_data = json.dumps(data).replace("None", "null").replace('""', "null")
+        statement = f"INSERT INTO {table_name} `{raw_data}`"
         self.qldb_driver.execute_lambda(lambda x: self.execute(x, statement))
 
 
     def update_data(self, table_name, primary_key_field, primary_key_value, data):
-        raw_data = str(data).replace("None", "null")
+        raw_data = str(data).replace("None", "null").replace('""', "null")
 
         statement = f"""
             UPDATE {table_name} AS x 
